<?php
	/**
	 *	Charge la liste des projets présents dans la base de données
	 * @param $db : l'instance de base de données.
	 * @return $listProject : le tableau contenant la liste des projets.
	 */
	function &loadListProject($db){
		/* Initialisation des variables */
		$i = 0;
		$listProject = null;
		
		/* Construction de la requête */
		$query = "SELECT libelle_projet, id_projet ".
					"FROM	Projet";	

		/* Exécution de la requête */
		$result = $db->execQuery($query);
		
		/* Construction du conteneur résultat */
		while($row = $db->nextObject($result)){
			$listProject[$i++] = $row;
		}
		
		return $listProject;
	}
	
	function &getProjectById($db, $id_projet){
		$query = "SELECT * ".
					"FROM Projet ".
					"WHERE id_projet=".$id_projet;
					
		/* Exécution de la requête */
		$result = $db->execQuery($query);
		/* Récupération du tuple */
		$row = $db->nextObject($result);
		
		return $row;
	}
	
	function &getLocById($db, $id_projet){
		$query = "SELECT PF.LOC ".
					"FROM Projet P, Pointsfonction PF ".
					"WHERE P.id_projet=".$id_projet." ".
					"AND P.id_pointsfonction = PF.id_pointsfonction";

		/* Exécution de la requête */
		$result = $db->execQuery($query);
		/* Récupération du tuple */
		$row = $db->nextObject($result);
		
		return $row;					
	}
	
	function &getFullInformationById($db, $id_projet){
		/* Chargement des informations sur les points de fonction */
		$query = "SELECT * ".
					"FROM Pointsfonction PF, Projet P ".
					"WHERE P.id_projet=".$id_projet." ".
					"AND P.id_pointsfonction = PF.id_pointsfonction ";
					
		/* Exécution de la requête */
		$result = $db->execQuery($query);
		/* Récupération du tuple */
		$row['pointsfonction'] = $db->nextObject($result);
		
		/* Chargement des informations sur la méthode COCOMO */
		$query = "SELECT * ".
					"FROM Cocomo C, Projet P ".
					"WHERE P.id_projet=".$id_projet." ".
					"AND P.id_cocomo = C.id_cocomo ";
					
		/* Exécution de la requête */
		$result = $db->execQuery($query);
		/* Récupération du tuple */
		$row['cocomo'] = $db->nextObject($result);		
		
		/* Si les tuples sont vides, on initialise les informations avec une valeur par défaut */
		if(empty($row['pointsfonction'])){
			$row['pointsfonction']->UFC 	= "0";		$row['pointsfonction']->TCF = "0";
			$row['pointsfonction']->PF 	= "0";		$row['pointsfonction']->LOC = "0";
		}	
		if(empty($row['cocomo'])){
			$row['cocomo']->UFC 	= "0";	$row['cocomo']->type_cocomo 	= "0";	$row['cocomo']->temps_dev 		= "0";
			$row['cocomo']->TCF 	= "0";	$row['cocomo']->mode_cocomo 	= "0";	$row['cocomo']->taille_equipe = "0";
			$row['cocomo']->PF 	= "0";	$row['cocomo']->kloc 			= "0";
			$row['cocomo']->LOC 	= "0";	$row['cocomo']->effort 			= "0";
		}

		return $row;
	}
	
	function &getCocomoFactorsByType($db, $type){
		$facteurs = null;
		
		$query = "SELECT * ".
					"FROM FacteursCocomo ".
					"WHERE type_cocomo like '".$type."' ".
					"ORDER BY type_cocomo";
					
		/* Exécution de la requête */
		$result = $db->execQuery($query);
		/* Construction du conteneur résultat */
		while($row = $db->nextObject($result)){
			$facteurs[utf8_encode($row->type_calcul)][utf8_encode($row->mode_cocomo)]['a'] = $row->a;
			$facteurs[utf8_encode($row->type_calcul)][utf8_encode($row->mode_cocomo)]['b'] = $row->b;
		}
			
		return $facteurs;
	}
	
	function &loadCocomoFactors($db){
		/* Initialisation */
		$i = 0;
		/* Construction de la requête */
		$query = "SELECT * ".
					"FROM FacteursCocomo ".
					"ORDER BY type_cocomo, type_calcul, id_facteurscocomo";
					
		/* Exécution de la requête */
		$result = $db->execQuery($query);
		/* Construction du conteneur résultat */
		while($row = $db->nextObject($result))
			$listFactors[$i++] = $row;

		return $listFactors;
	}
	
	function &loadPert($db, $id_projet){
		/* Initialisation */
		$i = 0;
		
		/* Construction de la requête */
		$query = "SELECT * FROM Tache T, Pert Pt, Projet P ".
					"WHERE P.id_projet=".$id_projet." ".
					"AND P.id_pert=Pt.id_pert ".
					"AND Pt.id_tache = T.id_tache";
					
		/* Exécution de la requête */
		$result = $db->execQuery($query);
		while($row = $db->nextObject($result)){
			$PertData[$i]->lettre_tache = $row->lettre_tache;
			$PertData[$i]->duree = $row->duree;
			$PertData[$i]->libelle_tache = $row->libelle_tache;
			$PertData[$i]->datePlusTot = $row->datePlusTot;
			$PertData[$i]->datePlusTard = $row->datePlusTard;
			$PertData[$i]->finPlusTot = $row->finPlusTot;
			$PertData[$i]->finPlusTard = $row->finPlusTard;
			$PertData[$i]->marge = $row->marge;
			$PertData[$i]->predecesseur = $row->predecesseur;
			$PertData[$i++]->libelle_pert = $row->libelle_pert;
		}
			
		
		return $PertData;
	}
?>